@@ -33,7 +33,7 @@ var searchData=
   ['to_20x11_30',['Relation to X11',['../index.html#relation-to-x11',1,'']]],
   ['to_20xkb_31',['Introduction to XKB',['../xkb-intro.html',1,'']]],
   ['todo_20list_32',['Todo List',['../todo.html',1,'']]],
-  ['tools_33',['Tools',['../index.html#tools',1,'Tools'],['../release-notes.html#tools-1',1,'Tools'],['../release-notes.html#tools-2',1,'Tools'],['../release-notes.html#tools-3',1,'Tools'],['../release-notes.html#tools-4',1,'Tools'],['../release-notes.html#tools-5',1,'Tools'],['../release-notes.html#tools-6',1,'Tools'],['../release-notes.html#tools-7',1,'Tools'],['../release-notes.html#tools-8',1,'Tools']]],
+  ['tools_33',['Tools',['../index.html#tools',1,'Tools'],['../release-notes.html#tools-1',1,'Tools'],['../release-notes.html#tools-2',1,'Tools'],['../release-notes.html#tools-3',1,'Tools'],['../release-notes.html#tools-4',1,'Tools'],['../release-notes.html#tools-5',1,'Tools'],['../release-notes.html#tools-6',1,'Tools'],['../release-notes.html#tools-7',1,'Tools'],['../release-notes.html#tools-8',1,'Tools'],['../release-notes.html#tools-9',1,'Tools'],['../release-notes.html#tools-10',1,'Tools']]],
   ['tools_34',['tools',['../debugging.html#advanced-tools',1,'Advanced tools'],['../debugging.html#available-tools',1,'Available tools'],['../debugging.html#basic-tools',1,'Basic tools']]],
   ['tools_20replacement_35',['Legacy X tools replacement',['../faq.html#legacy-x-tools-replacement',1,'']]],
   ['transformations_36',['Keysym Transformations',['../group__keysyms.html',1,'']]],
