@@ -10,7 +10,7 @@ var searchData=
   ['file_20encoding_7',['XKB-542 – Invalid file encoding',['../error-index.html#XKB-542',1,'']]],
   ['file_20names_8',['Using system file names',['../user-configuration.html#user-config-system-file-names',1,'']]],
   ['file_20not_20found_9',['XKB-338 – Included file not found',['../error-index.html#XKB-338',1,'']]],
-  ['fixes_10',['Fixes',['../release-notes.html#fixes',1,'Fixes'],['../release-notes.html#fixes-1',1,'Fixes'],['../release-notes.html#fixes-2',1,'Fixes'],['../release-notes.html#fixes-3',1,'Fixes'],['../release-notes.html#fixes-4',1,'Fixes'],['../release-notes.html#fixes-5',1,'Fixes'],['../release-notes.html#fixes-6',1,'Fixes'],['../release-notes.html#fixes-7',1,'Fixes'],['../release-notes.html#fixes-8',1,'Fixes'],['../release-notes.html#fixes-9',1,'Fixes'],['../release-notes.html#fixes-10',1,'Fixes'],['../release-notes.html#fixes-11',1,'Fixes'],['../release-notes.html#fixes-12',1,'Fixes'],['../release-notes.html#fixes-13',1,'Fixes'],['../release-notes.html#fixes-14',1,'Fixes'],['../release-notes.html#fixes-15',1,'Fixes']]],
+  ['fixes_10',['Fixes',['../release-notes.html#fixes',1,'Fixes'],['../release-notes.html#fixes-1',1,'Fixes'],['../release-notes.html#fixes-2',1,'Fixes'],['../release-notes.html#fixes-3',1,'Fixes'],['../release-notes.html#fixes-4',1,'Fixes'],['../release-notes.html#fixes-5',1,'Fixes'],['../release-notes.html#fixes-6',1,'Fixes'],['../release-notes.html#fixes-7',1,'Fixes'],['../release-notes.html#fixes-8',1,'Fixes'],['../release-notes.html#fixes-9',1,'Fixes'],['../release-notes.html#fixes-10',1,'Fixes'],['../release-notes.html#fixes-11',1,'Fixes'],['../release-notes.html#fixes-12',1,'Fixes'],['../release-notes.html#fixes-13',1,'Fixes'],['../release-notes.html#fixes-14',1,'Fixes'],['../release-notes.html#fixes-15',1,'Fixes'],['../release-notes.html#fixes-16',1,'Fixes'],['../release-notes.html#fixes-17',1,'Fixes'],['../release-notes.html#fixes-18',1,'Fixes']]],
   ['flags_11',['flags',['../keymap-text-format-v1-v2.html#generic-flags',1,'Generic flags'],['../keymap-text-format-v1-v2.html#section-flags-def',1,'Section flags'],['../keymap-text-format-v1-v2.html#symbols-flags',1,'Symbols flags']]],
   ['flags_20actions_12',['Control flags actions',['../keymap-text-format-v1-v2.html#control-flags-actions',1,'']]],
   ['format_13',['format',['../keymap-text-format-v1-v2.html#introduction-to-the-xkb-text-format',1,'Introduction to the XKB text format'],['../xkbcommon-compatibility.html#keymap-text-format',1,'Keymap text format'],['../todo.html#_todo000004',1,'Keymap text format'],['../release-notes.html#keymap-text-format-1',1,'Keymap text format'],['../release-notes.html#rules-text-format',1,'Rules text format'],['../xkb-intro.html#xkb-the-text-format',1,'XKB the text format'],['../todo.html#_todo000001',1,'XKB the text format'],['../error-index.html#XKB-742',1,'XKB-742 – Incompatible keymap text format']]],
